@@ -1,4 +1,5 @@
 import os
+from django.core.management import CommandError
 from bower.management.base import AppDirectoryCommand
 
 
@@ -6,4 +7,6 @@ class Command(AppDirectoryCommand):
     def handle_app(self, app_path):
         if os.path.exists(os.path.join(app_path, 'bower.json')):
             os.chdir(app_path)
-            os.system('bower install')
\ No newline at end of file
+            if os.system('bower install') != 0:
+                raise CommandError("Bower encountered an issue while "
+                                   "installing.")
\ No newline at end of file
